export declare type MessageFun = (msg: string, options?: any) => void;
/**
 * 消息提示接口
 */
export interface MessageHandler {
    /**
     * 成功消息
     */
    success: MessageFun;
    /**
     * 普通消息
     */
    info: MessageFun;
    /**
     * 警告消息
     */
    warning: MessageFun;
    /**
     * 错误消息
     */
    error: MessageFun;
}
/**
 * 消息类型
 */
export type MessageType = `${string & keyof MessageHandler}`;
/**
 * 消息处理函数, 默认使用console
 */
export declare const consoleMessageHandler: MessageHandler;
export interface MessageOptions {
    /**
     * 消息处理函数
     */
    messageHandler: MessageHandler;
}
/**
 * 使用消息函数，用来显示提示消息
 * @param msgType 消息类型
 * @returns
 */
export declare function useMessage(): MessageHandler;
export declare function useMessage(msgType: MessageType): MessageFun;
/**
 * 设置消息处理对象
 * @param _msg
 */
export declare const setupMessage: (options: MessageOptions) => void;
